@@ -1619,7 +1619,7 @@ TEST_CASE("Regression: Issue53|Channels", "[issue53]") {
 
   std::vector<tinyexr::LayerChannel> channels;
   tinyexr::ChannelsInLayer(header, "", channels);
-  REQUIRE(8 == channels.size());
+  REQUIRE(0 == channels.size());
 
   channels.clear();
   tinyexr::ChannelsInLayer(header, "Warstwa 3", channels);
@@ -1653,16 +1653,22 @@ TEST_CASE("Regression: Issue53|Image", "[issue53]") {
   int width, height;
   float* image;
   ret = LoadEXRWithLayer(&image, &width, &height, filepath.c_str(), NULL, &err);
-  REQUIRE(TINYEXR_SUCCESS == ret);
-  free(image);
+  REQUIRE(TINYEXR_SUCCESS != ret);
+  if (TINYEXR_SUCCESS == ret) {
+    free(image);
+  }
   if (err) {
     FreeEXRErrorMessage(err);
+    err = nullptr;
   }
 
   ret = LoadEXRWithLayer(&image, &width, &height, filepath.c_str(), "Warstwa 1",
                          &err);
   REQUIRE(TINYEXR_SUCCESS == ret);
-  free(image);
+  if (TINYEXR_SUCCESS == ret) {
+    free(image);
+  }
+
   if (err) {
     FreeEXRErrorMessage(err);
   }
@@ -1712,3 +1718,28 @@ TEST_CASE("Regression: PR150|Read|1x1 1xhalf", "[pr150]") {
   FreeEXRHeader(&header);
   FreeEXRImage(&image);
 }
+
+TEST_CASE("Regression: Issue194|Piz", "[issue194]") {
+  std::string filepath = "./regression/000-issue194.exr";
+
+  EXRVersion exr_version;
+  std::cout << "Loading" << filepath << std::endl;
+  int ret = ParseEXRVersionFromFile(&exr_version, filepath.c_str());
+  REQUIRE(TINYEXR_SUCCESS == ret);
+
+  EXRVersion version;
+  EXRHeader header;
+  EXRImage image;
+  InitEXRHeader(&header);
+  InitEXRImage(&image);
+
+  const char* err;
+  ret = ParseEXRHeaderFromFile(&header, &exr_version, filepath.c_str(), &err);
+  REQUIRE(TINYEXR_SUCCESS == ret);
+
+  ret = LoadEXRImageFromFile(&image, &header, filepath.c_str(), &err);
+  REQUIRE(TINYEXR_SUCCESS == ret);
+
+  FreeEXRHeader(&header);
+  FreeEXRImage(&image);
+}
